Documentation of sedpy
======================

Sedpy contains modules for storing and operating on astronomical source
spectral energy distributions.  In particular it can be used for projecting
spectra onto comon or user defined photometric filter systems, and contains
ustilities for smoothing spectra.

.. image:: https://github.com/bd-j/sedpy/workflows/Tests/badge.svg
  :target: https://github.com/bd-j/sedpy/actions?query=workflow%3ATests

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation.rst
   transmissions.rst
   quickstart.md


.. toctree::
   :maxdepth: 2
   :caption: API Reference

